diff --git a/gstlal-burst/bin/gstlal_excesspower_trigvis b/gstlal-burst/bin/gstlal_excesspower_trigvis
index 81af76574653bfbfdf4865e9627c4bc30547f86c..f8fd6788fca8f40cc642405d11d8cd897e4bc6ca 100755
--- a/gstlal-burst/bin/gstlal_excesspower_trigvis
+++ b/gstlal-burst/bin/gstlal_excesspower_trigvis
@@ -47,7 +47,7 @@ from glue.ligolw import table
 from glue.ligolw import ligolw
 lsctables.use_in(ligolw.LIGOLWContentHandler)
 from ligo import segments
-from glue.lal import LIGOTimeGPS
+from lal import LIGOTimeGPS
 from glue.lal import Cache
 
 from optparse import OptionParser
diff --git a/gstlal-burst/python/excesspower/parts.py b/gstlal-burst/python/excesspower/parts.py
index 5a27886ea71ba2f534407ae4b9995391fee69ffa..db58f2fc27ea4f939daa65c918c30147761a9349 100644
--- a/gstlal-burst/python/excesspower/parts.py
+++ b/gstlal-burst/python/excesspower/parts.py
@@ -56,7 +56,7 @@ from glue.ligolw.utils import process as ligolw_process
 from glue.ligolw.utils import segments as ligolw_segments
 from glue.ligolw.utils import search_summary as ligolw_search_summary
 
-from glue.segments import segment, segmentlist, segmentlistdict, PosInfinity
+from ligo.segments import segment, segmentlist, segmentlistdict, PosInfinity
 from glue.lal import Cache
 
 from pylal import datatypes as laltypes
diff --git a/gstlal-burst/python/excesspower/scan.py b/gstlal-burst/python/excesspower/scan.py
index dea26005922366133234f40b64d1551092877d68..919fbdf04e2e1aea3d0cc542503f85a583fde490 100644
--- a/gstlal-burst/python/excesspower/scan.py
+++ b/gstlal-burst/python/excesspower/scan.py
@@ -28,8 +28,7 @@ import tempfile
 
 import numpy
 
-from glue.segments import segment
-from glue.lal import LIGOTimeGPS, Cache, CacheEntry
+from ligo.segments import segment
 
 from gstlal import pipeparts
 from gstlal.excesspower.utils import EXCESSPOWER_UNIT_SCALE
diff --git a/gstlal-inspiral/python/stats/trigger_rate.py b/gstlal-inspiral/python/stats/trigger_rate.py
index 26323f2188ea9a63443e3f6666613cbf1c6ecebc..c296431f04af32deb3322232e6bd029c8bf62c6d 100644
--- a/gstlal-inspiral/python/stats/trigger_rate.py
+++ b/gstlal-inspiral/python/stats/trigger_rate.py
@@ -49,7 +49,7 @@ __all__ = ["ratebin", "ratebinlist", "triggerrates"]
 
 class ratebin(segments.segment):
 	"""
 	A version of the segment class (see glue.segments) that carries a
 	count of things.  Arithmetic operations update the count by
 	interpreting the count as a uniform density of things throughout
 	the interval spanned by the segment.  For example, the intersection
@@ -217,7 +217,7 @@ class ratebin(segments.segment):
 
 class ratebinlist(segments.segmentlist):
 	"""
-	Modified version of the segmentlist type (see glue.segments) whose
+	Modified version of the segmentlist type (see ligo.segments) whose
 	arithmetic operations implement the segment-and-count arithmetic
 	operations defined by the ratebin type.
@@ -49,7 +49,7 @@ __all__ = ["ratebin", "ratebinlist", "triggerrates"]
 class ratebin(segments.segment):
 	"""
-	A version of the segment class (see glue.segments) that carries a
+	A version of the segment class (see ligo.segments) that carries a
 	count of things.  Arithmetic operations update the count by
 	interpreting the count as a uniform density of things throughout